/*
    Copyright (C) 2005-2007  Erik van Pienbroek

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef _NNTPGRAB_TYPES_H_
#define _NNTPGRAB_TYPES_H_

typedef struct _config_server {
    char servername[128];
    char hostname[128];
    int port;
    char username[64];
    char password[64];
    int max_threads;
    int priority;
    gboolean use_ssl;
} ConfigServer;

typedef struct _config_opts {
    char download_directory[256];
    char temp_directory[256];
    gboolean show_notification_on_file_downloaded;
    gboolean show_notification_on_file_decoded;
} ConfigOpts;

typedef struct __config_group_info {
    char newsgroup[256];
    gboolean is_subscribed;
    gboolean is_moderated;
    int num_articles;
    int start_article;
    int end_article;
    time_t last_checked;
} ConfigGroupInfo;

typedef struct _nntpgrab_part {
    char message_id[256];
    int size;
    int partnum;
} NNTPGrabPart;

typedef enum {
    CONFIG_CHANGED_NOTHING,
    CONFIG_CHANGED_SERVER_ADDED,
    CONFIG_CHANGED_SERVER_DELETED,
    CONFIG_CHANGED_OPTS_CHANGED
} ConfigChangedFlag;

typedef enum {
    SCHEDULAR_STATE_RUNNING,
    SCHEDULAR_STATE_STOPPING,
    SCHEDULAR_STATE_STOPPED
} SchedularState;

typedef enum _nntp_disconnect_type {
    DISCONNECT_NORMAL,
    DISCONNECT_NO_SUCH_HOST,
    DISCONNECT_CONNECTION_REFUSED,
    DISCONNECT_TOO_MANY_CONNECTIONS,
    DISCONNECT_CONNECT_TIMEOUT,
    DISCONNECT_READ_ERROR,
    DISCONNECT_READ_TIMEOUT,
    DISCONNECT_WRITE_ERROR,
    DISCONNECT_IDLE_TIMEOUT,
    DISCONNECT_INVALID_MSG,
    DISCONNECT_LOGIN_FAILURE,
    DISCONNECT_UNEXPECTED,
} NNTPDisconnectType;

typedef enum _nntp_file_type {
    FILE_TYPE_RAR,
    FILE_TYPE_PAR,
    FILE_TYPE_PAR2,
    FILE_TYPE_SFV,
    FILE_TYPE_NFO,
    FILE_TYPE_NZB,
    FILE_TYPE_OTHER
} NNTPFileType;

typedef void (*ForeachCollectionFunc) (const char *collection_name, guint64 total_size, gpointer data);
typedef void (*ForeachFileFunc) (const char *collection_name, const char *subject, const char *poster, time_t stamp, guint64 file_size, int position, int num_parts_total, int num_parts_downloaded, int num_parts_failed, gpointer data);
typedef void (*ForeachGroupFunc) (const char *collection_name, const char *subject, const char *group, gpointer data);

#endif /* _NNTPGRAB_TYPES_H_ */
